summaryrefslogtreecommitdiff
path: root/filter/f-inst.c
diff options
context:
space:
mode:
authorMaria Matejka <mq@ucw.cz>2022-05-30 12:03:03 +0200
committerMaria Matejka <mq@ucw.cz>2022-05-30 14:39:09 +0200
commit938742decc6e1d6d3a0375dd012b75172e747bbc (patch)
treea10d9eb2811af43075c2c5272ece7b3dbbb38cdf /filter/f-inst.c
parent950775f6fa3d569a9d7cd05e33538d35e895d688 (diff)
Squashing the route attribute structure into one level.
For now, all route attributes are stored as eattrs in ea_list. This should make route manipulation easier and it also allows for a layered approach of route attributes where updates from filters will be stored as an overlay over the previous version.
Diffstat (limited to 'filter/f-inst.c')
-rw-r--r--filter/f-inst.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/filter/f-inst.c b/filter/f-inst.c
index c2abd5aa..65a0b011 100644
--- a/filter/f-inst.c
+++ b/filter/f-inst.c
@@ -212,7 +212,7 @@
* m4_dnl NEVER_CONSTANT-> don't generate pre-interpretation code at all
* m4_dnl ACCESS_RTE -> check that route is available, also NEVER_CONSTANT
* m4_dnl ACCESS_EATTRS -> pre-cache the eattrs; use only with ACCESS_RTE
* m4_dnl f_rta_cow(fs) -> function to call before any change to route should be done
*
* m4_dnl If you are stymied, see FI_CALL or FI_CONSTANT or just search for
* m4_dnl the mentioned macros in this file to see what is happening there in wild.
@@ -578,7 +578,7 @@
STATIC_ATTR;
ARG_TYPE(1, sa.type);
- f_rta_cow(fs);
+ f_rte_cow(fs);
{
union {
struct nexthop_adata nha;
@@ -741,7 +741,7 @@
if (da->type >= EAF_TYPE__MAX)
bug("Unsupported attribute type");
- f_rta_cow(fs);
+ f_rte_cow(fs);
switch (da->type) {
case T_OPAQUE:
@@ -770,7 +770,7 @@
ACCESS_RTE;
ACCESS_EATTRS;
- f_rta_cow(fs);
+ f_rte_cow(fs);
ea_unset_attr(fs->eattrs, 1, da);
}
@@ -212,7 +212,7 @@
* m4_dnl ACCESS_RTE -> check that route is available, also NEVER_CONSTANT
* m4_dnl ACCESS_EATTRS -> pre-cache the eattrs; use only with ACCESS_RTE
- * m4_dnl f_rta_cow(fs) -> function to call before any change to route should be done
+ * m4_dnl f_rte_cow(fs) -> function to call before any change to route should be done
*
* m4_dnl If you are stymied, see FI_CALL or FI_CONSTANT or just search for